@@ -7,9 +7,8 @@ import webbrowser
 from .helpers import credentials
 
 URL = "https://github.com/%s"
-NETRC_MACHINE = "api.github.com"
 
 
 def main(_):
-    username, _ = credentials.credentials(NETRC_MACHINE)
+    username, _ = credentials.credentials()
     webbrowser.open_new_tab(URL % username)
